@@ -16,8 +16,7 @@
 #' \item\code{GenerateRV}, a generic function that generates random variates from an object, together with a method for objects of class \sQuote{CopApprox}.
 #' }
 #'
-#' @references Tajvidi, N. and Turlach, B.A. (2017). A general approach to generate random variates for multivariate copulae, \emph{Australian & New Zealand Journal of Statistics}. Doi:10.1111/anzs.12209.
+#' @references Tajvidi, N. and Turlach, B.A. (2017). A general approach to generate random variates for multivariate copulae, \emph{Australian & New Zealand Journal of Statistics} \bold{60}(1): 140--155. \doi{10.1111/anzs.12209}.
 #'
-#' @docType package
 #' @name SimCop
-NULL
+"_PACKAGE"
